
package Email::Blaster::StartupHandler;

use strict;
use warnings 'all';
use base 'Email::Blaster::EventHandler';


#==============================================================================
sub run
{
  my ($s, $event) = @_;
}# end run()

1;# return true:

